level

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2021 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Level

type Level int8
const (
	Trace Level = iota
	Debug
	Info
	Warn
	Error
	Fatal
)

func Parse

func Parse(text string) (Level, error)

func (Level) String

func (lvl Level) String() string

Directories

Path Synopsis
Package filter provides a data structure to filter messages based on level
Package filter provides a data structure to filter messages based on level

Jump to