transform

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2021 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package transform converts a build message into different formats

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FieldToJSONType

func FieldToJSONType(fld field.Field) (interface{}, bool)

func FieldToText

func FieldToText(fld field.Field) (string, bool)

func FieldsToJSONType

func FieldsToJSONType(msg message.Message) map[string]interface{}

func FieldsToText

func FieldsToText(msg message.Message) string

func FieldsToTextJSON

func FieldsToTextJSON(msg message.Message) string

func ToJSON

func ToJSON(msg message.Message) string

func ToText

func ToText(msg message.Message) string

func ToTextConfigured

func ToTextConfigured(msg message.Message, config Config) string

Types

type Config

type Config struct {
	Timestamp    bool
	Tags         bool
	Level        bool
	Fields       bool
	BuildPainter func(io.StringWriter) paint.Painter
}
var DefaultConfig Config
var EverythingConfig Config

Directories

Path Synopsis
Package text provides utilities to parse back a message converted to text into machine-parsable data
Package text provides utilities to parse back a message converted to text into machine-parsable data

Jump to